==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/pl.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Potwierdź certyfikat SSL",
    "Delete server" : "Usuń serwer",
    "Add new server" : "Dodaj nowy serwer",
    "Saved" : "Zapisano",
    "Shared secret" : "Współdzielony kod",
    "TURN server shared secret" : "Wpółdzielony kod serwera TURN",
    "TURN server protocols" : "Protokoły serwera TURN",
    "UDP and TCP" : "UDP i TCP",
    "UDP only" : "Tylko UDP",
    "TCP only" : "Tylko TCP",
    "Screensharing is not supported by your browser." : "Współdzielenie ekranu nie jest wspierane przez Twoją przeglądarkę.",
    "Screensharing requires the page to be loaded through HTTPS." : "Współdzielenie ekrany wymaga, aby strona została załadowana przez HTTPS.",
    "Screensharing options" : "Opcje współdzielenia ekranu",
    "Sharing your screen only works with Firefox version 52 or newer." : "Współdzielenie twojego ekranu działa tylko z Firefoksem w wersji 52 lub nowszym.",
    "Screensharing extension is required to share your screen." : "Aby współdzielić ekran wymagane jest rozszerzenie do współdzeielenia ekranu",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Aby współdzielić ekran proszę użyć innej przeglądarki jak Firefox lub Chrome.",
    "An error occurred while starting screensharing." : "Wystąpił błąd podczas rozpoczynania współdzielenia ekranu.",
    "Participants" : "Uczestnicy",
    "Chat" : "Czat",
    "Talk" : "Rozmowa",
    "Waiting for {participantName} to join the call …" : "Oczekiwanie na {participantName} by przyłączyć się do rozmowy…",
    "Waiting for others to join the call …" : "Czekamy na innych aby przyłączyć się do rozmowy…",
    "Fullscreen (f)" : "Pełny ekran (f)",
    "No Camera" : "Brak kamery",
    "Enable screensharing" : "Włącz współdzielenie ekranu",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Share screen" : "Współdziel ekran",
    "Show your screen" : "Pokaż swój ekran",
    "Stop screensharing" : "Zatrzymaj współdzielenie ekranu",
    "Please enter the password for this call" : "Wprowadź hasło dla tej rozmowy",
    "Password required" : "Wymagane hasło",
    "Password" : "Hasło",
    "Cancel" : "Anuluj",
    "Submit" : "Zatwierdź",
    "Leave call" : "Opuść rozmowę",
    "Join call" : "Dołącz do rozmowy",
    "Share link" : "Udostępnij odnośnik",
    "Change password" : "Zmień hasło",
    "Set password" : "Ustaw hasło",
    "Name" : "Nazwa",
    "Rename" : "Zmień nazwę",
    "Copy link" : "Kopiuj odnośnik",
    "Conversation with {name}" : "Rozmowa z {name}",
    "Error occurred while setting password" : "Wystąpił błąd podczas ustawiania hasła",
    "Link copied!" : "Odnośnik skopiowany!",
    "You" : "Ty",
    "No messages yet, start the conversation!" : "Brak wiadomości, zacznij rozmowę!",
    "New message …" : "Nowa wiadomość…",
    "Send" : "Wyślij",
    "Guest" : "Gość",
    "[Unknown user name]" : "[Nieznana nazwa użytkownika]",
    "Today" : "Dzisiaj",
    "Yesterday" : "Wczoraj",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Podczas wysyłania wiadomości wystąpił błąd",
    "Edit" : "Edytuj",
    "moderator" : "moderator",
    "Demote from moderator" : "Degraduj z moderatora",
    "Promote to moderator" : "Promuj na moderatora",
    "Remove participant" : "Usuń uczestnika",
    "No other people in this call" : "W tej rozmowie nie uczestniczą inne osoby",
    "You can invite others in the participant tab of the sidebar" : "Można zaprosić inne osoby w zakładce Uczestnicy na pasku bocznym",
    "Share this link to invite others!" : "Udostępniaj ten link aby zapraszać innych!",
    "Close" : "Zakończ",
    "Waiting for camera and microphone permissions" : "Czekam na zezwolenie uprawnień dla mikrofonu i kamery",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Proszę dać swojej przeglądarce uprawnienia do użycia kamery i mikrofonu, aby używać tej aplikacji",
    "Disable video" : "Wyłącz wideo.",
    "Show screen" : "Pokaż ekran",
    "Access to microphone & camera is only possible with HTTPS" : "Dostęp do mikrofonu i kamery możliwe jest tylko za pomocą protokołu HTTPS",
    "Access to microphone & camera was denied" : "Dostępu do mikrofonu i kamery został odrzucony",
    "WebRTC is not supported in your browser" : "WebRTC nie jest wspierana przez Twoją przeglądarkę.",
    "Please use a different browser like Firefox or Chrome" : "Proszę użyć innej przeglądarki jak Firefox czy Chrome",
    "Error while accessing microphone & camera" : "Wystąpił błąd podczas dostępu do mikrofonu i kamery",
    "WebRTC is not supported in your browser :-/" : "WebRTC nie jest wspierana przez Twoją przeglądarkę :-/",
    "{participantName}'s screen" : "Ekran {participantName}",
    "Guest's screen" : "Ekran gościa",
    "Your screen" : "Twój ekran",
    "(Duration %s)" : "(Czas trwania %s)",
    "You attended a call with {user1}" : "Udział w rozmowie z {user1}",
    "_%n guest_::_%n guests_" : ["%n gość","%gości","%n gości","%n gości"],
    "You attended a call with {user1} and {user2}" : "Udział w rozmowie z {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Udział w rozmowie z {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Udział w rozmowie z {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Udział w rozmowie z {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["innym","%ninnymi","%n innymi","%n innymi"],
    "{actor} invited you to {call}" : "{actor} zaprosił Cię do {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Otrzymano zaproszenie do pokoju <strong>rozmów</strong> lub masz <strong>rozmowę</strong>",
    "Talk to %s" : "Rozmawiaj z %s",
    "_%n other guest_::_%n other guests_" : ["%n inny gość","%n inni goście","%n inni goście","%n inni goście"],
    ", " : ",",
    "{user} wants to talk with you" : "{user} chce z Tobą rozmawiać",
    "A group call has started in {call}" : "Rozmowa grupowa została rozpoczęta w {call}",
    "A group call has started" : "Rozmowa grupowa została rozpoczęta",
    "This call is password-protected" : "Ta rozmowa jest zabezpieczona hasłem",
    "The password is wrong. Try again." : "Błędne hasło. Spróbuj ponownie.",
    "Signaling server" : "Serwer sygnałowy",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Zewnętrzny serwer sygnałowy może zostać opcjonalnie użyty dla większych instalacji. Zostaw puste aby używać serwera wewnętrznego.",
    "STUN servers" : "Serwery STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
    "TURN server" : "TURN serwer",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serwer TURN jest używany do przekazywania ruchu od uczestników za firewallem.",
    "Video calls" : "Wideo rozmowy",
    "(group)" : "(grupa)",
    "New public call" : "Nowa publiczna rozmowa",
    "Looking great today! :)" : "Świetnie dzisiaj wyglądasz! :)",
    "Time to call your friends" : "Czas zadzwonić do Twoich przyjaciół",
    "You can set your name on the top right of this page so other participants can identify you better." : "Możesz ustawić swoje imię w prawym górnym rogu tej strony, tak aby inni uczestnicy mogli lepiej Cię poznać.",
    "This call has ended" : "Zakończono rozmowę",
    "Saving failed" : "Zapisywanie nie powiodło się",
    "Add person" : "Dodaj osobę",
    "and you" : "i ty",
    "Please adjust your configuration" : "Proszę ustawić konfigurację",
    "{actor} invited you to a private call" : "{actor} zaprosił(a) cię na prywatną rozmowę",
    "{actor} invited you to a group call" : "{actor} zaprosił(a) cię do rozmowy grupowej",
    "{actor} invited you to the call {call}" : "{actor} zaprosił(a) cię do rozmowy {call}",
    "You were invited to a <strong>video call</strong>" : "Otrzymano zaproszenie do <strong> rozmowy wideo</string>",
    "Video call" : "Rozmowa wideo",
    "Invalid format, must be stunserver:port." : "Nieprawidłowy format, musi być stunserver:port.",
    "Invalid port specified." : "Podano nieprawidłowy port.",
    "Invalid protocols specified." : "Podano nieprawidłowy protokół.",
    "%s invited you to a private call" : "%s zaprosił(a) Cię do prywatnej rozmowy",
    "{user} invited you to a private call" : "{user} zaprosił(a) Cię do prywatnej rozmowy",
    "%s invited you to a group call: %s" : "%s zaprosił(a) cię do grupowej rozmowy: %s",
    "{user} invited you to a group call: {call}" : "{user} zaprosił(a) cię do grupowej rozmowy: {call}",
    "%s invited you to a group call" : "%s zaprosił(a) Cię do grupowej rozmowy",
    "{user} invited you to a group call" : "{user} zaprosił(a) Cię do grupowej rozmowy",
    "Fullscreen" : "Pełny ekran",
    "Mute audio" : "Wyciszenie audio",
    "Smile in 3… 2… 1!" : "Uśmiechnij się 3… 2… 1!",
    "Choose person …" : "Wybierz osobę…",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Serwer STUN jest niezbędny aby umożliwić uczestnikom połączenie się do rozmów. Serwer TURN zapewnia, że połączenie będzie działać niezależnie od ustawień zapór sieciowych.",
    "STUN server" : "STUN serwer",
    "The STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/pl.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Potwierdź certyfikat SSL",
    "Delete server" : "Usuń serwer",
    "Add new server" : "Dodaj nowy serwer",
    "Saved" : "Zapisano",
    "Shared secret" : "Współdzielony kod",
    "TURN server shared secret" : "Wpółdzielony kod serwera TURN",
    "UDP and TCP" : "UDP i TCP",
    "UDP only" : "Tylko UDP",
    "TCP only" : "Tylko TCP",
    "TURN server protocols" : "Protokoły serwera TURN",
    "New public conversation" : "Nowa publiczna rozmowa",
    "New group conversation" : "Nowa rozmowa grupowa",
    "New conversation …" : "Nowa rozmowa ...",
    "Screensharing is not supported by your browser." : "Współdzielenie ekranu nie jest wspierane przez Twoją przeglądarkę.",
    "Screensharing requires the page to be loaded through HTTPS." : "Współdzielenie ekrany wymaga, aby strona została załadowana przez HTTPS.",
    "Screensharing options" : "Opcje współdzielenia ekranu",
    "Sharing your screen only works with Firefox version 52 or newer." : "Współdzielenie twojego ekranu działa tylko z Firefoksem w wersji 52 lub nowszym.",
    "Screensharing extension is required to share your screen." : "Aby współdzielić ekran wymagane jest rozszerzenie do współdzeielenia ekranu",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Aby współdzielić ekran proszę użyć innej przeglądarki jak Firefox lub Chrome.",
    "An error occurred while starting screensharing." : "Wystąpił błąd podczas rozpoczynania współdzielenia ekranu.",
    "Participants" : "Uczestnicy",
    "Chat" : "Czat",
    "Talk" : "Rozmowa",
    "Waiting for {participantName} to join the call …" : "Oczekiwanie na {participantName} by przyłączyć się do rozmowy…",
    "Waiting for others to join the call …" : "Czekamy na innych aby przyłączyć się do rozmowy…",
    "Exit fullscreen (f)" : "Wyjdź z trybu pełnoekranowego (f)",
    "Fullscreen (f)" : "Tryb pełnoekranowy (f)",
    "Mute audio (m)" : "Wycisz dźwięk (m)",
    "Unmute audio (m)" : "Wyłącz wyciszenie dźwięku (m)",
    "No audio" : "Brak dźwięku",
    "Disable video (v)" : "Wyłącz wideo (v)",
    "Enable video (v)" : "Włącz wideo (v)",
    "Set your name in the chat window so other participants can identify you better." : "Ustaw swoje imię w oknie czatu, aby inni mogli Cię zidentyfikować.",
    "No Camera" : "Brak kamery",
    "Enable screensharing" : "Włącz współdzielenie ekranu",
    "Copy" : "Kopiuj",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Brak wsparcia!",
    "Press ⌘-C to copy." : "Wciśnij ⌘-C by skopiować.",
    "Press Ctrl-C to copy." : "Wciśnij Ctrl-C by skopiować.",
    "Join a conversation or start a new one" : "Dołącz do konwersacji lub rozpocznij nową",
    "This conversation has ended" : "Konwersacja została zakończona",
    "Request password" : "Zażądaj hasła",
    "Share screen" : "Współdziel ekran",
    "Show your screen" : "Pokaż swój ekran",
    "Stop screensharing" : "Zatrzymaj współdzielenie ekranu",
    "Error requesting the password." : "Błąd żądania hasła.",
    "Please enter the password for this call" : "Wprowadź hasło dla tej rozmowy",
    "Password required" : "Wymagane hasło",
    "Password" : "Hasło",
    "Cancel" : "Anuluj",
    "Submit" : "Zatwierdź",
    "Leave call" : "Opuść rozmowę",
    "Join call" : "Dołącz do rozmowy",
    "Start call" : "Rozpocznij rozmowę",
    "Share link" : "Udostępnij odnośnik",
    "Change password" : "Zmień hasło",
    "Set password" : "Ustaw hasło",
    "Name" : "Nazwa",
    "Conversation name" : "Nazwa konwersacji",
    "Rename" : "Zmień nazwę",
    "Copy link" : "Kopiuj odnośnik",
    "Conversation with {name}" : "Rozmowa z {name}",
    "Error occurred while setting password" : "Wystąpił błąd podczas ustawiania hasła",
    "Link copied!" : "Odnośnik skopiowany!",
    "You" : "Ty",
    "No messages yet, start the conversation!" : "Brak wiadomości, zacznij rozmowę!",
    "New message …" : "Nowa wiadomość…",
    "Send" : "Wyślij",
    "Share" : "Udostępnij",
    "Guest" : "Gość",
    "[Unknown user name]" : "[Nieznana nazwa użytkownika]",
    "Today" : "Dzisiaj",
    "Yesterday" : "Wczoraj",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Podczas wysyłania wiadomości wystąpił błąd",
    "Edit" : "Edytuj",
    "moderator" : "moderator",
    "Demote from moderator" : "Degraduj z moderatora",
    "Promote to moderator" : "Promuj na moderatora",
    "Remove participant" : "Usuń uczestnika",
    "No other people in this call" : "W tej rozmowie nie uczestniczą inne osoby",
    "You can invite others in the participant tab of the sidebar" : "Można zaprosić inne osoby w zakładce Uczestnicy na pasku bocznym",
    "Share this link to invite others!" : "Udostępniaj ten link aby zapraszać innych!",
    "Close" : "Zakończ",
    "Waiting for camera and microphone permissions" : "Czekam na zezwolenie uprawnień dla mikrofonu i kamery",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Proszę dać swojej przeglądarce uprawnienia do użycia kamery i mikrofonu, aby używać tej aplikacji",
    "Disable video" : "Wyłącz wideo.",
    "Show screen" : "Pokaż ekran",
    "Access to microphone & camera is only possible with HTTPS" : "Dostęp do mikrofonu i kamery możliwe jest tylko za pomocą protokołu HTTPS",
    "Access to microphone & camera was denied" : "Dostępu do mikrofonu i kamery został odrzucony",
    "WebRTC is not supported in your browser" : "WebRTC nie jest wspierana przez Twoją przeglądarkę.",
    "Please use a different browser like Firefox or Chrome" : "Proszę użyć innej przeglądarki jak Firefox czy Chrome",
    "Error while accessing microphone & camera" : "Wystąpił błąd podczas dostępu do mikrofonu i kamery",
    "WebRTC is not supported in your browser :-/" : "WebRTC nie jest wspierana przez Twoją przeglądarkę :-/",
    "{participantName}'s screen" : "Ekran {participantName}",
    "Guest's screen" : "Ekran gościa",
    "Your screen" : "Twój ekran",
    "(Duration %s)" : "(Czas trwania %s)",
    "You attended a call with {user1}" : "Udział w rozmowie z {user1}",
    "_%n guest_::_%n guests_" : ["%n gość","%gości","%n gości","%n gości"],
    "You attended a call with {user1} and {user2}" : "Udział w rozmowie z {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Udział w rozmowie z {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Udział w rozmowie z {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Udział w rozmowie z {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["innym","%ninnymi","%n innymi","%n innymi"],
    "{actor} invited you to {call}" : "{actor} zaprosił Cię do {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Otrzymano zaproszenie do pokoju <strong>rozmów</strong> lub masz <strong>rozmowę</strong>",
    "Talk to %s" : "Rozmawiaj z %s",
    "_%n other guest_::_%n other guests_" : ["%n inny gość","%n inni goście","%n inni goście","%n inni goście"],
    ", " : ",",
    "{user} wants to talk with you" : "{user} chce z Tobą rozmawiać",
    "A group call has started in {call}" : "Rozmowa grupowa została rozpoczęta w {call}",
    "A group call has started" : "Rozmowa grupowa została rozpoczęta",
    "This call is password-protected" : "Ta rozmowa jest zabezpieczona hasłem",
    "The password is wrong. Try again." : "Błędne hasło. Spróbuj ponownie.",
    "Signaling server" : "Serwer sygnałowy",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Zewnętrzny serwer sygnałowy może zostać opcjonalnie użyty dla większych instalacji. Zostaw puste aby używać serwera wewnętrznego.",
    "STUN servers" : "Serwery STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
    "TURN server" : "TURN serwer",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serwer TURN jest używany do przekazywania ruchu od uczestników za firewallem.",
    "Video calls" : "Wideo rozmowy",
    "(group)" : "(grupa)",
    "New public call" : "Nowa publiczna rozmowa",
    "Looking great today! :)" : "Świetnie dzisiaj wyglądasz! :)",
    "Time to call your friends" : "Czas zadzwonić do Twoich przyjaciół",
    "You can set your name on the top right of this page so other participants can identify you better." : "Możesz ustawić swoje imię w prawym górnym rogu tej strony, tak aby inni uczestnicy mogli lepiej Cię poznać.",
    "This call has ended" : "Zakończono rozmowę",
    "Saving failed" : "Zapisywanie nie powiodło się",
    "Add person" : "Dodaj osobę",
    "and you" : "i ty",
    "Please adjust your configuration" : "Proszę ustawić konfigurację",
    "{actor} invited you to a private call" : "{actor} zaprosił(a) cię na prywatną rozmowę",
    "{actor} invited you to a group call" : "{actor} zaprosił(a) cię do rozmowy grupowej",
    "{actor} invited you to the call {call}" : "{actor} zaprosił(a) cię do rozmowy {call}",
    "You were invited to a <strong>video call</strong>" : "Otrzymano zaproszenie do <strong> rozmowy wideo</string>",
    "Video call" : "Rozmowa wideo",
    "Invalid format, must be stunserver:port." : "Nieprawidłowy format, musi być stunserver:port.",
    "Invalid port specified." : "Podano nieprawidłowy port.",
    "Invalid protocols specified." : "Podano nieprawidłowy protokół.",
    "%s invited you to a private call" : "%s zaprosił(a) Cię do prywatnej rozmowy",
    "{user} invited you to a private call" : "{user} zaprosił(a) Cię do prywatnej rozmowy",
    "%s invited you to a group call: %s" : "%s zaprosił(a) cię do grupowej rozmowy: %s",
    "{user} invited you to a group call: {call}" : "{user} zaprosił(a) cię do grupowej rozmowy: {call}",
    "%s invited you to a group call" : "%s zaprosił(a) Cię do grupowej rozmowy",
    "{user} invited you to a group call" : "{user} zaprosił(a) Cię do grupowej rozmowy",
    "Fullscreen" : "Pełny ekran",
    "Mute audio" : "Wyciszenie audio",
    "Smile in 3… 2… 1!" : "Uśmiechnij się 3… 2… 1!",
    "Choose person …" : "Wybierz osobę…",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "Serwer STUN jest niezbędny aby umożliwić uczestnikom połączenie się do rozmów. Serwer TURN zapewnia, że połączenie będzie działać niezależnie od ustawień zapór sieciowych.",
    "STUN server" : "STUN serwer",
    "The STUN server is used to determine the public IP address of participants behind a router." : "Serwer STUN jest wykorzystywany do określania publicznego adresu IP uczestników znajdujących się za routerem.",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
